@@ -3,7 +3,8 @@ import json
 import math
 import random
 import re
-from typing import Any, Dict, List
+import shlex
+from typing import Any, Dict, List, Union
 
 from chaoslib.exceptions import ActivityFailed
 from chaoslib.types import Secrets
@@ -77,7 +78,7 @@ def terminate_pods(
 
 
 def exec_in_pods(
-    cmd: str,
+    cmd: Union[str, List[str]],
     label_selector: str = None,
     name_pattern: str = None,
     all: bool = False,
@@ -112,6 +113,11 @@ def exec_in_pods(
 
     If `rand` is set to `True`, n random pods will be affected
     Otherwise, the first retrieved n pods will be used
+
+    The `cmd` should be a string or a sequence of program arguments. Providing
+    a sequence of arguments is generally preferred, as it allows the action to
+    take care of any required escaping and quoting (e.g. to permit spaces in the
+    arguments). If passing a single string it will be split automatically.
     """
     if not cmd:
         raise ActivityFailed("A command must be set to run a container")
@@ -123,7 +129,7 @@ def exec_in_pods(
         v1, label_selector, name_pattern, all, rand, mode, qty, ns, order
     )
 
-    exec_command = cmd.strip().split()
+    exec_command = shlex.split(cmd) if isinstance(cmd, str) else cmd
 
     results = []
     for po in pods:
@@ -152,12 +158,22 @@ def exec_in_pods(
 
         resp.run_forever(timeout=request_timeout)
 
-        err = json.loads(resp.read_channel(ERROR_CHANNEL))
         out = resp.read_channel(STDOUT_CHANNEL)
+        err = resp.read_channel(ERROR_CHANNEL).strip()
 
-        if err["status"] != "Success":
+        try:
+            err = json.loads(err)
+        except json.decoder.JSONDecodeError:
+            logger.debug(
+                "Failed loading pod exec error stream as a json payload", exc_info=True
+            )
+
+        if isinstance(err, dict) and (err["status"] != "Success"):
             error_code = err["details"]["causes"][0]["message"]
             error_message = err["message"]
+        elif isinstance(err, str):
+            error_code = 1
+            error_message = err
         else:
             error_code = 0
             error_message = ""
